# Repositório de disciplina Sistemas de Apoio à Decisão (SAD)

Bem-vindo ao repositório do projeto da disciplina de Sistemas de Apoio à Decisão!

Este repositório foi criado para compartilhar os projetos desenvolvidos pelos alunos como parte da disciplina. Aqui há uma variedade de Método de decisão multi critério implementados em python e utilizando diversas abordagens.

## Instruções para os alunos

1. Faça um fork deste repositório.
2. Crie uma nova branch para o grupo.
3. Vá para a pasta específica do grupo (dentro da pasta do período).
4. Suba o código do grupo nessa pasta, com documentação completa no readme e todas as dependências necessárias para rodar o código no requirements.txt, caso seja necessário (basta rodar o comando pip freeze > requirements.txt).

    4.1. Obs.: Lembrar de colocar os autores do código no readme do grupo.

5. Abrir um PR para submissão.

## Licença
Este projeto está licenciado sob os termos da Licença MIT. Consulte o arquivo LICENSE para obter mais informações.
